@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 use English qw{ -no_match_vars };
-use PPIx::Regexp 0.057; # To force version.
+use PPIx::Regexp 0.070; # For is_quantifier()
 use Readonly;
 
 use Perl::Critic::Exception::Configuration::Option::Policy::ParameterValue
@@ -14,7 +14,7 @@ use Perl::Critic::Utils qw< :booleans :characters hashify :severities >;
 
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '0.000_901';
+our $VERSION = '0.000_902';
 # The problem we are solving with the following is that older Perls do
 # not like the underscore in a development version number. I do not
 # believe this violates the spirit of the disabled policy.
